********************************************************************************
********************************************************************************
* 						THE COVID-19 CONSUMPTION GAME-CHANGER:
*					EVIDENCE FROM A LARGE-SCALE MULTI-COUNTRY SURVEY		  
* 								    
* 					(Italy, Spain, France, Germany, Netherlands)
*
* 	AUTHORS: Alexander Hodbod; Cars Hommes; Stefanie J. Huber; Isabelle Salle
********************************************************************************


********************************************************************************
* Note: This do-file conducts the analysis (tables and graphs)
********************************************************************************

clear all
set more off

use "data/master_readytogo.dta", clear


********************************************************************************

* 			SUMMARY STATS

********************************************************************************

********************************************************************************
* TABLE A1: total number of observations by country 	
********************************************************************************
	tab country
	table country

********************************************************************************
* TABLE A2: Socio-Economic Characteristics (I) by country (age, gender, household size, education)
********************************************************************************
tabstat age male nchild nadult householdsize loweduc mideduc higheduc, stat(mean sd count) by(country) columns(variables) format(%9.2f)


********************************************************************************
* TABLE A3: Socio-Economic Characteristics (II) by country (employment & savings)
********************************************************************************

tabstat job notinLF unemployed pastunempl savings incomefeel, stat(mean sd count) by(country) columns(variables) format(%9.2f)

********************************************************************************
* TABLE A4: Socio-Economic Characteristics (III) by country (income)
********************************************************************************
tabstat income10, stat(mean sd p10 p25 p50 p75 p90 count) by(country)  format(%9.2f)

********************************************************************************
* TABLE 1: COVID-19 infection exposure 
********************************************************************************
 
tabstat infection, stat(mean sd count) by(country) format(%9.2f)

********************************************************************************
* TABLE 2/PANEL B: COVID-19 related financial concerns by country 
********************************************************************************
 tabstat worryfinance, stat(mean sd p10 p25 p50 p75 p90 count) by(country) 

 
********************************************************************************
* TABLE 2/PANEL A: COVID-19 related concerns to lose job by country 
********************************************************************************
 
tabstat worryjobloss, stat(mean sd p10 p25 p50 p75 p90 count) by(country) format(%9.2f)
 
********************************************************************************
* TABLE 3: Expectations about the end of COVID-19 crisis
********************************************************************************
 
bysort country: tabulate crisisend
 
********************************************************************************
* TABLE 4: Expectations about unemployment
********************************************************************************
 
bysort country: sum unempl_before 
bysort country: sum unempl_now 
bysort country: sum unempl_1year 
bysort country: sum unempl_2years 


********************************************************************************
* TABLE 5: Trust and Satisfaction with the goverment
********************************************************************************
 
 tabstat trust, stat(mean sd p10 p25 p50 p75 p90 count) by(country) format(%9.2f)

 tabstat satisfaction, stat(mean sd p10 p25 p50 p75 p90 count) by(country) format(%9.2f)

 
********************************************************************************
* TABLE 6: Cross-Country Correlations
********************************************************************************
   
* Panel A 	
 tabstat deaths infection worryjobloss worryfinance crisisend unempl_1year trust satisfaction, stat(mean) by(country) format(%9.2f)

* Panel B
* Cross-country correlations calculated in Excel: file called Table6.xlsx

 
********************************************************************************
********************************************************************************
* TABLES: REASON-GROUPS DISTRIBUTION ACROSS COUNTRIES
********************************************************************************
********************************************************************************

  tab country if whytransportclean==1
  tab country if whytravelclean==1
  tab country if whyservicesclean==1
  tab country if whyrestaurantsclean2==1
  tab country if whyshopsclean2==1
 
  tab country if whytransportclean==2
  tab country if whytravelclean==2
  tab country if whyservicesclean==2
  tab country if whyrestaurantsclean2==2
  tab country if whyshopsclean2==2
 
  tab country if whytransportclean==3
  tab country if whytravelclean==3
  tab country if whyservicesclean==3
  tab country if whyrestaurantsclean2==3
  tab country if whyshopsclean2==3
 
  tab country if whytransportclean==4
  tab country if whytravelclean==4
  tab country if whyservicesclean==4
  tab country if whyrestaurantsclean2==4
  tab country if whyshopsclean2==4
 
  tab country if whyrestaurantsclean2==6
  tab country if whyshopsclean2==6
 
********************************************************************************
********************************************************************************
* TABLE A9: STATISTICS FOR DIFFERENT REASON GROUPS
********************************************************************************
********************************************************************************

 * First generate for each sector the mean of all socio-econ characteristics by reason of consumption drop (whole sample)

 
 codebook whytransportclean
 codebook whytravelclean
 codebook whyservicesclean
 codebook whyrestaurantsclean 
 codebook whyshopsclean
 
 tabstat age male householdsize loweduc mideduc higheduc, stat(mean ) by(whytransportclean) columns(variables) format(%9.2f)

 tabstat age male householdsize loweduc mideduc higheduc, stat(mean ) by(whytravelclean) columns(variables) format(%9.2f)

 tabstat age male householdsize loweduc mideduc higheduc, stat(mean ) by(whyservicesclean) columns(variables) format(%9.2f)

 tabstat age male householdsize loweduc mideduc higheduc, stat(mean ) by(whyrestaurantsclean) columns(variables) format(%9.2f)

 tabstat age male householdsize loweduc mideduc higheduc, stat(mean ) by(whyshopsclean) columns(variables) format(%9.2f)

 
 tabstat job notinLF unemployed pastunempl savings incomefeel income10, stat(mean ) by(whytransportclean) columns(variables) format(%9.2f)

 tabstat job notinLF unemployed pastunempl savings incomefeel income10, stat(mean ) by(whytravelclean) columns(variables) format(%9.2f)

 tabstat job notinLF unemployed pastunempl savings incomefeel income10, stat(mean ) by(whyservicesclean) columns(variables) format(%9.2f)

 tabstat job notinLF unemployed pastunempl savings incomefeel income10, stat(mean ) by(whyrestaurantsclean) columns(variables) format(%9.2f)

 tabstat job notinLF unemployed pastunempl savings incomefeel income10, stat(mean ) by(whyshopsclean) columns(variables) format(%9.2f)

 * Second, do nonparametric tests Wilcoxon-Mann-Whitney & standard T-tests
 
 *PUBLIC TRANSPORTS
********************************************************************************
 * Compare not missing it & wanting to save more

ttest age if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum age if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest male if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum male if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest householdsize if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum householdsize if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest loweduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum loweduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest mideduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum mideduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest higheduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum higheduc if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest job if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum job if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest notinLF if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum notinLF if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest unemployed if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum unemployed if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest pastunempl if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum pastunempl if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest savings if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum savings if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest incomefeel if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum incomefeel if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest income10 if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum income10 if whytransportclean==1|whytransportclean==2, by(whytransportclean)

********************************************************************************
 * Compare not missing it & infection risk

ttest age if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum age if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest male if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum male if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest householdsize if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum householdsize if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest loweduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum loweduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest mideduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum mideduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest higheduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum higheduc if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest job if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum job if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest notinLF if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum notinLF if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest unemployed if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum unemployed if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest pastunempl if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum pastunempl if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest savings if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum savings if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest incomefeel if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum incomefeel if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest income10 if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum income10 if whytransportclean==1|whytransportclean==4, by(whytransportclean)
 
 
******************************************************************************** 
  * Compare not missing it & not affordable
  
ttest age if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum age if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest male if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum male if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest householdsize if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum householdsize if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest loweduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum loweduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest mideduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum mideduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest higheduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum higheduc if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest job if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum job if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest notinLF if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum notinLF if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest unemployed if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum unemployed if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest pastunempl if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum pastunempl if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest savings if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum savings if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest incomefeel if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum incomefeel if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest income10 if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum income10 if whytransportclean==1|whytransportclean==3, by(whytransportclean)
********************************************************************************


 * Sector: TOURISM
********************************************************************************
 * Compare not missing it & wanting to save more

ttest age if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum age if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest male if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum male if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest householdsize if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum householdsize if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest loweduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum loweduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest mideduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum mideduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest higheduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum higheduc if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest job if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum job if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest notinLF if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum notinLF if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest unemployed if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum unemployed if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest savings if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum savings if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest incomefeel if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum incomefeel if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest income10 if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum income10 if whytravelclean==1|whytravelclean==2, by(whytravelclean)

********************************************************************************
 * Compare not missing it & infection risk

ttest age if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum age if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest male if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum male if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest householdsize if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum householdsize if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest loweduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum loweduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest mideduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum mideduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest higheduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum higheduc if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest job if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum job if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest notinLF if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum notinLF if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest unemployed if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum unemployed if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest savings if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum savings if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest incomefeel if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum incomefeel if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest income10 if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum income10 if whytravelclean==1|whytravelclean==4, by(whytravelclean)
 
******************************************************************************** 
  * Compare not missing it & not affordable
 
ttest age if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum age if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest male if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum male if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest householdsize if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum householdsize if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest loweduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum loweduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest mideduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum mideduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest higheduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum higheduc if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest job if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum job if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest notinLF if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum notinLF if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest unemployed if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum unemployed if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest savings if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum savings if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest incomefeel if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum incomefeel if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest income10 if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum income10 if whytravelclean==1|whytravelclean==3, by(whytravelclean)

 * Sector: SERVICES 
********************************************************************************
 * Compare not missing it & wanting to save more

ttest age if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum age if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest male if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum male if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest householdsize if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum householdsize if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest loweduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum loweduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest mideduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum mideduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest higheduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum higheduc if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest job if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum job if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest notinLF if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum notinLF if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest unemployed if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum unemployed if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest savings if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum savings if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest incomefeel if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum incomefeel if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest income10 if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum income10 if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)


********************************************************************************
 * Compare not missing it & infection risk


ttest age if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum age if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest male if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum male if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest householdsize if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum householdsize if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest loweduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum loweduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest mideduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum mideduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest higheduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum higheduc if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest job if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum job if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest notinLF if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum notinLF if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest unemployed if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum unemployed if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest savings if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum savings if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest incomefeel if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum incomefeel if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest income10 if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum income10 if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

 
******************************************************************************** 
  * Compare not missing it & not affordable
 
ttest age if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum age if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest male if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum male if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest householdsize if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum householdsize if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest loweduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum loweduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest mideduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum mideduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest higheduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum higheduc if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest job if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum job if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest notinLF if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum notinLF if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest unemployed if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum unemployed if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest savings if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum savings if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest incomefeel if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum incomefeel if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest income10 if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum income10 if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
 
 * Sector: Hospitality
********************************************************************************
 * Compare not missing it & wanting to save more

ttest age if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum age if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest male if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum male if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest job if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum job if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest savings if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum savings if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)


********************************************************************************
 * Compare not missing it & infection risk

ttest age if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum age if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest male if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum male if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest job if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum job if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest savings if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum savings if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

 
******************************************************************************** 
  * Compare not missing it & not affordable
 

ttest age if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum age if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest male if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum male if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum householdsize if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum loweduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum mideduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum higheduc if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest job if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum job if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum notinLF if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum unemployed if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest savings if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum savings if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum incomefeel if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum income10 if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

 * Sector: RETAIL
********************************************************************************
 * Compare not missing it & wanting to save more

ttest age if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum age if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest male if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum male if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest householdsize if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum householdsize if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest loweduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum loweduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest mideduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum mideduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest higheduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum higheduc if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest job if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum job if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest notinLF if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum notinLF if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest unemployed if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum unemployed if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest savings if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum savings if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest incomefeel if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum incomefeel if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest income10 if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum income10 if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

********************************************************************************
 * Compare not missing it & infection risk

ttest age if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum age if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest male if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum male if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest householdsize if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum householdsize if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest loweduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum loweduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest mideduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum mideduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest higheduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum higheduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest job if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum job if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest notinLF if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum notinLF if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest unemployed if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum unemployed if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest savings if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum savings if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest incomefeel if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum incomefeel if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest income10 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum income10 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

 ******************************************************************************** 
  * Compare not missing it & not affordable

ttest age if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum age if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest male if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum male if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest householdsize if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum householdsize if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest loweduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum loweduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest mideduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum mideduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest higheduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum higheduc if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest job if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum job if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest notinLF if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum notinLF if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest unemployed if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum unemployed if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest savings if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum savings if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest incomefeel if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum incomefeel if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest income10 if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum income10 if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)



ttest age if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum age if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest male if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum male if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest householdsize if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum householdsize if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest loweduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum loweduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest mideduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum mideduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest higheduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum higheduc if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest job if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum job if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest notinLF if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum notinLF if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest unemployed if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum unemployed if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest savings if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum savings if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest incomefeel if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum incomefeel if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest income10 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum income10 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)


 
********************************************************************************
********************************************************************************
* TABLE A10: behavioral factors by primary reason for consuming less 
********************************************************************************
********************************************************************************
* experience variables: deaths infection pastunempl
* macroeconomic expectations: diffexp_unempl2 crisisend
* feelings towards governments: trust satisfaction
* concerns: worryfinance worryjobloss
 
 codebook whytransportclean
 codebook whytravelclean
 codebook whyservicesclean
 codebook whyrestaurantsclean 
 codebook whyshopsclean
 
 
 tabstat deaths infection, stat(mean ) by(whytransportclean) columns(variables) format(%9.2f)

 tabstat deaths infection, stat(mean ) by(whytravelclean) columns(variables) format(%9.2f)

 tabstat deaths infection, stat(mean ) by(whyservicesclean) columns(variables) format(%9.2f)

 tabstat deaths infection, stat(mean ) by(whyrestaurantsclean) columns(variables) format(%9.2f)

 tabstat deaths infection, stat(mean ) by(whyshopsclean) columns(variables) format(%9.2f)
 

 tabstat diffexp_unempl2 crisisend trust satisfaction worryjobloss worryfinance, stat(mean ) by(whytransportclean) columns(variables) format(%9.2f)

 tabstat diffexp_unempl2 crisisend trust satisfaction worryjobloss worryfinance, stat(mean ) by(whytravelclean) columns(variables) format(%9.2f)

 tabstat diffexp_unempl2 crisisend trust satisfaction worryjobloss worryfinance, stat(mean ) by(whyservicesclean) columns(variables) format(%9.2f)

 tabstat diffexp_unempl2 crisisend trust satisfaction worryjobloss worryfinance, stat(mean ) by(whyrestaurantsclean) columns(variables) format(%9.2f)

 tabstat diffexp_unempl2 crisisend trust satisfaction worryjobloss worryfinance, stat(mean ) by(whyshopsclean) columns(variables) format(%9.2f)

******************************************************************************* 
  *PUBLIC TRANSPORTS
********************************************************************************
 * Compare not missing it & wanting to save more

ttest deaths if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum deaths if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest infection if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum infection if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest diffexp_unempl2 if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum diffexp_unempl2 if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest crisisend if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum crisisend if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest trust if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum trust if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest satisfaction if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum satisfaction if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest worryjobloss if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum worryjobloss if whytransportclean==1|whytransportclean==2, by(whytransportclean)

ttest worryfinance if whytransportclean==1|whytransportclean==2, by(whytransportclean)
ranksum worryfinance if whytransportclean==1|whytransportclean==2, by(whytransportclean)

********************************************************************************
 * Compare not missing it & infection risk

ttest deaths if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum deaths if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest infection if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum infection if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest diffexp_unempl2 if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum diffexp_unempl2 if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest crisisend if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum crisisend if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest trust if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum trust if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest satisfaction if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum satisfaction if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest worryjobloss if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum worryjobloss if whytransportclean==1|whytransportclean==4, by(whytransportclean)

ttest worryfinance if whytransportclean==1|whytransportclean==4, by(whytransportclean)
ranksum worryfinance if whytransportclean==1|whytransportclean==4, by(whytransportclean)

******************************************************************************** 
  * Compare not missing it & not affordable
  
ttest deaths if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum deaths if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest infection if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum infection if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest diffexp_unempl2 if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum diffexp_unempl2 if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest crisisend if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum crisisend if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest trust if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum trust if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest satisfaction if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum satisfaction if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest worryjobloss if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum worryjobloss if whytransportclean==1|whytransportclean==3, by(whytransportclean)

ttest worryfinance if whytransportclean==1|whytransportclean==3, by(whytransportclean)
ranksum worryfinance if whytransportclean==1|whytransportclean==3, by(whytransportclean)

 
  * Sector: Tourism
********************************************************************************
 * Compare not missing it & wanting to save more

ttest deaths if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum deaths if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest infection if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum infection if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest diffexp_unempl2 if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum diffexp_unempl2 if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest crisisend if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum crisisend if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest trust if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum trust if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest satisfaction if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum satisfaction if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest worryjobloss if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum worryjobloss if whytravelclean==1|whytravelclean==2, by(whytravelclean)

ttest worryfinance if whytravelclean==1|whytravelclean==2, by(whytravelclean)
ranksum worryfinance if whytravelclean==1|whytravelclean==2, by(whytravelclean)

********************************************************************************
 * Compare not missing it & infection risk

ttest deaths if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum deaths if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest infection if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum infection if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest diffexp_unempl2 if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum diffexp_unempl2 if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest crisisend if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum crisisend if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest trust if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum trust if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest satisfaction if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum satisfaction if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest worryjobloss if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum worryjobloss if whytravelclean==1|whytravelclean==4, by(whytravelclean)

ttest worryfinance if whytravelclean==1|whytravelclean==4, by(whytravelclean)
ranksum worryfinance if whytravelclean==1|whytravelclean==4, by(whytravelclean)

******************************************************************************** 
  * Compare not missing it & not affordable
 
ttest deaths if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum deaths if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest infection if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum infection if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest pastunempl if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum pastunempl if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest diffexp_unempl2 if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum diffexp_unempl2 if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest crisisend if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum crisisend if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest trust if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum trust if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest satisfaction if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum satisfaction if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest worryjobloss if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum worryjobloss if whytravelclean==1|whytravelclean==3, by(whytravelclean)

ttest worryfinance if whytravelclean==1|whytravelclean==3, by(whytravelclean)
ranksum worryfinance if whytravelclean==1|whytravelclean==3, by(whytravelclean)
 
  * Sector: Services
********************************************************************************
 * Compare not missing it & wanting to save more

ttest deaths if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum deaths if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest infection if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum infection if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest diffexp_unempl2 if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum diffexp_unempl2 if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest crisisend if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum crisisend if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest trust if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum trust if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest satisfaction if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum satisfaction if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest worryjobloss if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum worryjobloss if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)

ttest worryfinance if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
ranksum worryfinance if whyservicesclean==1|whyservicesclean==2, by(whyservicesclean)
 
********************************************************************************
 * Compare not missing it & infection risk
ttest deaths if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum deaths if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest infection if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum infection if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest diffexp_unempl2 if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum diffexp_unempl2 if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest crisisend if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum crisisend if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest trust if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum trust if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest satisfaction if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum satisfaction if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest worryjobloss if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum worryjobloss if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)

ttest worryfinance if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
ranksum worryfinance if whyservicesclean==1|whyservicesclean==4, by(whyservicesclean)
 
******************************************************************************** 
  * Compare not missing it & not affordable

ttest deaths if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum deaths if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest infection if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum infection if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest pastunempl if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum pastunempl if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest diffexp_unempl2 if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum diffexp_unempl2 if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest crisisend if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum crisisend if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest trust if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum trust if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest satisfaction if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum satisfaction if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest worryjobloss if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum worryjobloss if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)

ttest worryfinance if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
ranksum worryfinance if whyservicesclean==1|whyservicesclean==3, by(whyservicesclean)
 
  * Sector: Hospitality
********************************************************************************
 * Compare not missing it & wanting to save more

ttest deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest infection if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum infection if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest trust if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum trust if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

ttest worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)
ranksum worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==2, by(whyrestaurantsclean2)

********************************************************************************
 * Compare not missing it & infection risk
 
ttest deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest infection if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum infection if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest trust if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum trust if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

ttest worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)
ranksum worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==4, by(whyrestaurantsclean2)

******************************************************************************** 
  * Compare not missing it & not affordable

ttest deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum deaths if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest infection if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum infection if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum pastunempl if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum diffexp_unempl2 if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum crisisend if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest trust if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum trust if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum satisfaction if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum worryjobloss if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)

ttest worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)
ranksum worryfinance if whyrestaurantsclean2==1|whyrestaurantsclean2==3, by(whyrestaurantsclean2)


  * Sector: Retail
********************************************************************************
 * Compare not missing it & wanting to save more

ttest deaths if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum deaths if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest infection if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum infection if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest crisisend if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum crisisend if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest trust if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum trust if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest satisfaction if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum satisfaction if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest worryjobloss if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum worryjobloss if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

ttest worryfinance if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)
ranksum worryfinance if whyshopsclean2==1|whyshopsclean2==2, by(whyshopsclean2)

********************************************************************************
 * Compare not missing it & infection risk
 
ttest deaths if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum deaths if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest infection if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum infection if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest crisisend if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum crisisend if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest trust if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum trust if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest satisfaction if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum satisfaction if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest worryjobloss if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum worryjobloss if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

ttest worryfinance if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)
ranksum worryfinance if whyshopsclean2==1|whyshopsclean2==4, by(whyshopsclean2)

******************************************************************************** 
  * Compare not missing it & not affordable

ttest deaths if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum deaths if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest infection if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum infection if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest pastunempl if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum pastunempl if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum diffexp_unempl2 if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest crisisend if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum crisisend if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest trust if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum trust if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest satisfaction if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum satisfaction if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest worryjobloss if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum worryjobloss if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)

ttest worryfinance if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
ranksum worryfinance if whyshopsclean2==1|whyshopsclean2==3, by(whyshopsclean2)
 
********************************************************************************
********************************************************************************
* BAR HISTOGRAMMS
********************************************************************************
********************************************************************************

********************************************************************************
* APPENDIX FIGURES A13-A17: 
********************************************************************************


histogram transport, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)70, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak, how would you behave?", size(medium) nobox) subtitle("I would use public transports")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)
                                      

histogram travel, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)70, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak, how would you behave?", size(medium) nobox) subtitle("I would travel abroad for private reasons")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)


histogram restaurants, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)70, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak, how would you behave?", size(medium) nobox) subtitle("I would visit restaurants, bars, and cafés")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)


histogram services, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)70, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak, how would you behave?", size(medium) nobox) subtitle("I would use services such as hairdressers or beauty salons" )) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)


histogram shops, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)70, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak, how would you behave?", size(medium) nobox) subtitle("I would shop in malls or other stores")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)


tabstat lesstransport, s(mean) by(countrycode) 

********************************************************************************
* FIGURES 2-6: LESS OFTEN - YES / NO
********************************************************************************


histogram lesstransport, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(0(1)1, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by( ,title("Compared to before the Covid-19 outbreak,", size(medium) nobox) subtitle("would you use public transports less often?")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total note("Source: Alex Hodbod, Cars Hommes, Stefanie J Huber, and Isabelle Salle (2020)," "Is COVID-19 a consumption game changer? Evidence from a large-scale multi-country survey," "Covid Economics Vetted and Real-Time Papers, Issue 59, pp. 40-76."))

histogram lesstravel, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(0(1)1, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak,", size(medium) nobox) subtitle("would you travel abroad for private reasons less often?")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)

histogram lessrestaurants, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(0(1)1, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak,", size(medium) nobox) subtitle("would you visit restaurants, bars, and cafés less often?")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)

histogram lessservices, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(0(1)1, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak,", size(medium) nobox) subtitle("would you use services such as hairdressers or beauty salons less often?")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)

histogram lessshops, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(0(1)1, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Compared to before the Covid-19 outbreak,", size(medium) nobox) subtitle("would you shop in malls or other stores less often?")) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)

********************************************************************************
* FIGURES 7-11: THE REASONS WHY CONSUMING LESS OFTEN THAN PRE-PANDEMIC 
********************************************************************************


histogram whytransportclean, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Main reason for using now less public transport:", size(medium) nobox)) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)
histogram whytravelclean, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Main reason for traveling now less abroad:", size(medium) nobox)) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)
histogram whyservicesclean, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(1(1)5, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Main reason for using now less services such as hairdressers:", size(medium) nobox)) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)
histogram whyrestaurantsclean, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(1(1)6, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Main reason for going now less to restaurants, bars, and cafés:", size(medium) nobox)) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)
histogram whyshopsclean, discrete percent fcolor(dknavy) lcolor(white) gap(2) addlabel ylabel(0(20)80, format(%9.0f)) xscale(off) xlabel(1(1)6, labels labsize(small) angle(vertical) format(%9.1f) valuelabel) xmtick(##1, labsize(small) valuelabel) by(, title("Main reason for shopping now less in malls or other stores:", size(medium) nobox)) by(, legend(off)) scheme(s2mono) by(, graphregion(lcolor(white))) by(country, total)


********************************************************************************
********************************************************************************
* REGRESSIONS: 
********************************************************************************
********************************************************************************


********************************************************************************
* TABLES 7-11: BY SECTOR 
********************************************************************************

* REGRESSION TABLE 7
probit lesstransport age male householdsize income10 i.empstat3 i.education_r2 , cluster(countrycode)
 		eststo model1a
		
 probit lesstransport age male householdsize income10 i.empstat3 i.education_r2 pastunempl infection, cluster(countrycode)
 		eststo model1b
		
 probit lesstransport age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend , cluster(countrycode)
 		eststo model1c
		
 probit lesstransport age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend worryfinance, cluster(countrycode)
 		eststo model1d

		esttab model1? using lesstransport.tex, pr2(2)  title("Public Transports: Socio-economic and Behavioral Factors") starlevels(* 0.1 ** 0.05 *** 0.01 ) replace margin se(2)

* REGRESSION TABLE 8		
 probit lesstravel age male householdsize income10 i.empstat3 i.education_r2 , cluster(countrycode)
 		eststo model1a
		
 probit lesstravel age male householdsize income10 i.empstat3 i.education_r2 pastunempl infection, cluster(countrycode)
 		eststo model1b
		
 probit lesstravel age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend , cluster(countrycode)
 		eststo model1c
		
 probit lesstravel age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend worryfinance, cluster(countrycode)
 		eststo model1d
		
		esttab model1? using lesstravel.tex, pr2(2)  title("Tourism: Socio-economic and Behavioral Factors") starlevels(* 0.1 ** 0.05 *** 0.01 ) replace margin se(2)

* REGRESSION TABLE 9	
probit lessservices age male householdsize income10 i.empstat3 i.education_r2 , cluster(countrycode)
 		eststo model1a
		
 probit lessservices age male householdsize income10 i.empstat3 i.education_r2 pastunempl infection, cluster(countrycode)
 		eststo model1b
		
 probit lessservices age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend , cluster(countrycode)
 		eststo model1c
		
 probit lessservices age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend worryfinance, cluster(countrycode)
 		eststo model1d
		
		esttab model1? using lessservices.tex, pr2(2)  title("Services: Socio-economic and Behavioral Factors") starlevels(* 0.1 ** 0.05 *** 0.01 ) replace margin se(2)
	
* REGRESSION TABLE 10		
probit lessrestaurants age male householdsize income10 i.empstat3 i.education_r2 , cluster(countrycode)
 		eststo model1a
		
 probit lessrestaurants age male householdsize income10 i.empstat3 i.education_r2 pastunempl infection, cluster(countrycode)
 		eststo model1b
		
 probit lessrestaurants age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend , cluster(countrycode)
 		eststo model1c
		
 probit lessrestaurants age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend worryfinance, cluster(countrycode)
 		eststo model1d
		
		esttab model1? using lessrestaurants.tex, pr2(2)  title("Hospitality: Socio-economic and Behavioral Factors") starlevels(* 0.1 ** 0.05 *** 0.01 ) replace margin se(2)

* REGRESSION TABLE 11
probit lessshops age male householdsize income10 i.empstat3 i.education_r2 , cluster(countrycode)
 		eststo model1a
		
 probit lessshops age male householdsize income10 i.empstat3 i.education_r2 pastunempl infection, cluster(countrycode)
 		eststo model1b
		
 probit lessshops age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend , cluster(countrycode)
 		eststo model1c
		
 probit lessshops age male householdsize income10 i.empstat3  i.education_r2 pastunempl infection  unempl_1year crisisend worryfinance, cluster(countrycode)
 		eststo model1d
		
		esttab model1? using lessshops.tex, pr2(2)  title("Retail: Socio-economic and Behavioral Factors") starlevels(* 0.1 ** 0.05 *** 0.01 ) replace margin se(2)
	


